@@ -4,7 +4,7 @@
 {-# LANGUAGE KindSignatures #-}
 module Types where
 
-import Language.Haskell.TH
+import Language.Haskell.TH.Lib
 import Language.Haskell.TH.Syntax
 import Util
 
@@ -19,7 +19,7 @@ type Int'' = Int
 type Id a = a
 
 -- type E x = forall y. Either x y -> Int
-$(sequence [tySynD (mkName "E") [PlainTV (mkName "x")]
+$(sequence [tySynD (mkName "E") [plainTV (mkName "x")]
                 (forallT'' ["y"] (conT ''Either `appT` varT' "x" `appT` varT' "y" --> conT ''Int))
            ])
 
